@@ -13,7 +13,7 @@ class TestThreading(object):
         self._thread_failed = False
         threads = [
             threading.Thread(target=self._get_bugs_thread, args=(pkg,))
-            for pkg in ('python3-gst-1.0', 'libsoxr0')
+            for pkg in ("python3-gst-1.0", "libsoxr0")
         ] + [
             threading.Thread(target=self._get_bug_log_thread, args=(bug_n,))
             for bug_n in (300000, 300001)
@@ -29,14 +29,14 @@ class TestThreading(object):
 
     def _get_bugs_thread(self, pkg):
         try:
-            bts.get_bugs('package', pkg)
+            bts.get_bugs("package", pkg)
         except Exception:
             self._thread_failed = True
-            logger.exception('Threaded get_bugs() call failed.')
+            logger.exception("Threaded get_bugs() call failed.")
 
     def _get_bug_log_thread(self, bug_num):
         try:
             bts.get_bug_log(bug_num)
         except Exception:
             self._thread_failed = True
-            logger.exception('Threaded get_bug_log() call failed.')
+            logger.exception("Threaded get_bug_log() call failed.")
